==> james-project-3.4.0-source-release.zip: james-project-3.4.0/mailbox/api/src/test/java/org/apache/james/mailbox/model/SearchQueryTest.java <==
/*
 *   Licensed to the Apache Software Foundation (ASF) under one
 *   or more contributor license agreements.  See the NOTICE file
 *   distributed with this work for additional information
 *   regarding copyright ownership.  The ASF licenses this file
 *   to you under the Apache License, Version 2.0 (the
 *   "License"); you may not use this file except in compliance
 *   with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing,
 *   software distributed under the License is distributed on an
 *   "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 *   KIND, either express or implied.  See the License for the
 *   specific language governing permissions and limitations
 *   under the License.
 *
 */

package org.apache.james.mailbox.model;

import static org.assertj.core.api.Assertions.assertThat;

import org.junit.Test;

import nl.jqno.equalsverifier.EqualsVerifier;

public class SearchQueryTest {

    @Test
    public void searchQueryShouldRespectBeanContract() {
        EqualsVerifier.forClass(SearchQuery.class)
            .withOnlyTheseFields("criterias")
            .verify();
    }

    @Test
    public void equalsShouldCompareCriteria() {
        SearchQuery searchQuery1 = new SearchQuery();
        SearchQuery searchQuery2 = new SearchQuery();
        searchQuery1.andCriteria(SearchQuery.all());
        searchQuery2.andCriteria(SearchQuery.all());

        assertThat(searchQuery1).isEqualTo(searchQuery2);
    }

}

==> james-project-3.5.0-source-release.zip: james-project-3.5.0/mailbox/api/src/test/java/org/apache/james/mailbox/model/SearchQueryTest.java <==
/*
 *   Licensed to the Apache Software Foundation (ASF) under one
 *   or more contributor license agreements.  See the NOTICE file
 *   distributed with this work for additional information
 *   regarding copyright ownership.  The ASF licenses this file
 *   to you under the Apache License, Version 2.0 (the
 *   "License"); you may not use this file except in compliance
 *   with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing,
 *   software distributed under the License is distributed on an
 *   "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 *   KIND, either express or implied.  See the License for the
 *   specific language governing permissions and limitations
 *   under the License.
 *
 */

package org.apache.james.mailbox.model;

import static org.assertj.core.api.Assertions.assertThat;

import org.junit.jupiter.api.Test;

import nl.jqno.equalsverifier.EqualsVerifier;

class SearchQueryTest {

    @Test
    void searchQueryShouldRespectBeanContract() {
        EqualsVerifier.forClass(SearchQuery.class)
            .withOnlyTheseFields("criterias")
            .verify();
    }

    @Test
    void equalsShouldCompareCriteria() {
        SearchQuery searchQuery1 = new SearchQuery();
        SearchQuery searchQuery2 = new SearchQuery();
        searchQuery1.andCriteria(SearchQuery.all());
        searchQuery2.andCriteria(SearchQuery.all());

        assertThat(searchQuery1).isEqualTo(searchQuery2);
    }

}
